/**
 * DK Maternity Facade API
 * This is the specification of the DK Maternity Facade API. It is a facade for the Web Services Resource Transfer DK Maternity API.
 *
 * OpenAPI spec version: 1.0.0
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */

import { Inject, Injectable, Optional } from '@angular/core';
import { HttpClient, HttpHeaders, HttpParams, HttpResponse, HttpEvent } from '@angular/common/http';
import { CustomHttpUrlEncodingCodec } from '../encoder';

import { Observable } from 'rxjs';

import { ApplicationContext } from '../model/applicationContext';
import { BreakTheGlassReason } from '../model/breakTheGlassReason';
import { CarePlan } from '../model/carePlan';
import { EditableCarePlan } from '../model/editableCarePlan';
import { ProblemDetails } from '../model/problemDetails';
import { UserRole } from '../model/userRole';
import { Uuidv4 } from '../model/uuidv4';

import { BASE_PATH, COLLECTION_FORMATS } from '../variables';
import { Configuration } from '../configuration';


@Injectable()
export class CarePlanService {

  protected basePath = '/';
  public defaultHeaders = new HttpHeaders();
  public configuration = new Configuration();

  constructor(
    protected httpClient: HttpClient,
    @Optional() @Inject(BASE_PATH) basePath: string,
    @Optional() configuration: Configuration
  ) {
    if (basePath) {
      this.basePath = basePath;
    }
    if (configuration) {
      this.configuration = configuration;
      this.basePath = basePath || configuration.basePath || this.basePath;
    }
  }

 /*
   * @param consumes string[] mime-types
   * @return true: consumes contains 'multipart/form-data', false: otherwise
   */
  private canConsumeForm(consumes: string[]): boolean {
    const form = 'multipart/form-data';
    for (const consume of consumes) {
      if (form === consume) {
        return true;
      }
    }
    return false;
  }


 /*
   * Get data cards
   * Gets all care plans for the current patient ((which is stored in the session and can be updated using PUT on the
   * /patientcontext endpoint)
   * @param context The context encoded as a JWT token, see [SessionContext](#/components/schemas/SessionContext)
   * @param xChosenRole The chosen user STS or SEB
   * @param xBreakTheGlassReason When set disables access controls for a well defined period of time or until the patient is changed
   * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
   * @param reportProgress flag to report request and response progress.
   */
  public maternityCarePlanGet(
    context: ApplicationContext,
    xChosenRole?: UserRole,
    xBreakTheGlassReason?: BreakTheGlassReason,
    observe?: 'body',
    reportProgress?: boolean
  ): Observable<Array<CarePlan>>;
  public maternityCarePlanGet(
    context: ApplicationContext,
    xChosenRole?: UserRole,
    xBreakTheGlassReason?: BreakTheGlassReason,
    observe?: 'response',
    reportProgress?: boolean
  ): Observable<HttpResponse<Array<CarePlan>>>;
  public maternityCarePlanGet(
    context: ApplicationContext,
    xChosenRole?: UserRole,
    xBreakTheGlassReason?: BreakTheGlassReason,
    observe?: 'events',
    reportProgress?: boolean
  ): Observable<HttpEvent<Array<CarePlan>>>;
  public maternityCarePlanGet(
    context: ApplicationContext,
    xChosenRole?: UserRole,
    xBreakTheGlassReason?: BreakTheGlassReason,
    observe: any = 'body',
    reportProgress: boolean = false
  ): Observable<any> {
    if (context === null || context === undefined) {
      throw new Error('Required parameter context was null or undefined when calling maternityCarePlanGet.');
    }

    let headers = this.defaultHeaders;
    if (!!xChosenRole) {
      headers = headers.set('X-Chosen-Role', String(xChosenRole));
    }
    if (!!xBreakTheGlassReason) {
      headers = headers.set('X-Break-The-Glass-Reason', String(xBreakTheGlassReason));
    }

    // authentication (application) required
    if (this.configuration.accessToken) {
      const accessToken = typeof this.configuration.accessToken === 'function'
        ? this.configuration.accessToken()
        : this.configuration.accessToken;
      headers = headers.set('Authorization', 'Bearer ' + accessToken);
    }

    // to determine the Accept header
    const httpHeaderAccepts: string[] = [
      'application/json',
      'application/problem+json'
    ];
    const httpHeaderAcceptSelected: string | undefined = this.configuration.selectHeaderAccept(httpHeaderAccepts);
    if (!!httpHeaderAcceptSelected) {
      headers = headers.set('Accept', httpHeaderAcceptSelected);
    }

    // to determine the Content-Type header
    const consumes: string[] = [];

    return this.httpClient.get(`${this.basePath}/maternity/care-plan`,
      {
        withCredentials: this.configuration.withCredentials,
        headers,
        observe,
        reportProgress
      }
    );
  }

 /*
   * Extend the care plan
   * Extend the care plan with the **identifier** specified in the URI with all activities specified in the template
   * provided it belongs to the current patient (which is stored in the session and can be updated using PUT on the
   * /patientcontext endpoint).
   * @param identifier The identifier of the care plan to extend
   * @param body the care-plan to update
   * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
   * @param reportProgress flag to report request and response progress.
   */
  public maternityCarePlanIdentifierExtendPatch(
    identifier: Uuidv4,
    body?: EditableCarePlan,
    observe?: 'body',
    reportProgress?: boolean
  ): Observable<CarePlan>;
  public maternityCarePlanIdentifierExtendPatch(
    identifier: Uuidv4,
    body?: EditableCarePlan,
    observe?: 'response',
    reportProgress?: boolean
  ): Observable<HttpResponse<CarePlan>>;
  public maternityCarePlanIdentifierExtendPatch(
    identifier: Uuidv4,
    body?: EditableCarePlan,
    observe?: 'events',
    reportProgress?: boolean
  ): Observable<HttpEvent<CarePlan>>;
  public maternityCarePlanIdentifierExtendPatch(
    identifier: Uuidv4,
    body?: EditableCarePlan,
    observe: any = 'body',
    reportProgress: boolean = false
  ): Observable<any> {
    if (identifier === null || identifier === undefined) {
      throw new Error('Required parameter identifier was null or undefined when calling maternityCarePlanIdentifierExtendPatch.');
    }

    let headers = this.defaultHeaders;

    // authentication (application) required
    if (this.configuration.accessToken) {
      const accessToken = typeof this.configuration.accessToken === 'function'
        ? this.configuration.accessToken()
        : this.configuration.accessToken;
      headers = headers.set('Authorization', 'Bearer ' + accessToken);
    }

    // to determine the Accept header
    const httpHeaderAccepts: string[] = [
      'application/json',
      'application/problem+json'
    ];
    const httpHeaderAcceptSelected: string | undefined = this.configuration.selectHeaderAccept(httpHeaderAccepts);
    if (!!httpHeaderAcceptSelected) {
      headers = headers.set('Accept', httpHeaderAcceptSelected);
    }

    // to determine the Content-Type header
    const consumes: string[] = [
      'application/json'
    ];
    const httpContentTypeSelected: string | undefined = this.configuration.selectHeaderContentType(consumes);
    if (!!httpContentTypeSelected) {
      headers = headers.set('Content-Type', httpContentTypeSelected);
    }

    return this.httpClient.patch(`${this.basePath}/maternity/care-plan/${encodeURIComponent(String(identifier))}/extend`,
      {
        withCredentials: this.configuration.withCredentials,
        headers,
        observe,
        reportProgress
      }
    );
  }

 /*
   * Get the care plan with the specified **identifier**
   * Gets the care plan with the **identifier** specified in the URI, provided it belongs to the current patient
   * (which is stored in the session and can be updated using PUT on the /patientcontext endpoint)
   * @param identifier The identifier of the care plan
   * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
   * @param reportProgress flag to report request and response progress.
   */
  public maternityCarePlanIdentifierGet(
    identifier: Uuidv4,
    observe?: 'body',
    reportProgress?: boolean
  ): Observable<CarePlan>;
  public maternityCarePlanIdentifierGet(
    identifier: Uuidv4,
    observe?: 'response',
    reportProgress?: boolean
  ): Observable<HttpResponse<CarePlan>>;
  public maternityCarePlanIdentifierGet(
    identifier: Uuidv4,
    observe?: 'events',
    reportProgress?: boolean
  ): Observable<HttpEvent<CarePlan>>;
  public maternityCarePlanIdentifierGet(
    identifier: Uuidv4,
    observe: any = 'body', reportProgress: boolean = false
  ): Observable<any> {
    if (identifier === null || identifier === undefined) {
      throw new Error('Required parameter identifier was null or undefined when calling maternityCarePlanIdentifierGet.');
    }

    let headers = this.defaultHeaders;

    // authentication (application) required
    if (this.configuration.accessToken) {
      const accessToken = typeof this.configuration.accessToken === 'function'
        ? this.configuration.accessToken()
        : this.configuration.accessToken;
      headers = headers.set('Authorization', 'Bearer ' + accessToken);
    }

    // to determine the Accept header
    const httpHeaderAccepts: string[] = [
      'application/json',
      'application/problem+json'
    ];
    const httpHeaderAcceptSelected: string | undefined = this.configuration.selectHeaderAccept(httpHeaderAccepts);
    if (!!httpHeaderAcceptSelected) {
      headers = headers.set('Accept', httpHeaderAcceptSelected);
    }

    // to determine the Content-Type header
    const consumes: string[] = [];

    return this.httpClient.get(`${this.basePath}/maternity/care-plan/${encodeURIComponent(String(identifier))}`,
      {
        withCredentials: this.configuration.withCredentials,
        headers,
        observe,
        reportProgress
      }
    );
  }

 /*
   * Update the care plan with the specified **identifier**
   * Updates the care plan with the **identifier** specified in the URI provided it belongs to the current patient
   * (which is stored in the session and can be updated using PUT on the /patientcontext endpoint).
   * @param identifier The identifier of the care plan
   * @param body the care-plan to update
   * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
   * @param reportProgress flag to report request and response progress.
   */
  public maternityCarePlanIdentifierPut(
    identifier: Uuidv4,
    body?: EditableCarePlan,
    observe?: 'body',
    reportProgress?: boolean
  ): Observable<CarePlan>;
  public maternityCarePlanIdentifierPut(
    identifier: Uuidv4,
    body?: EditableCarePlan,
    observe?: 'response',
    reportProgress?: boolean
  ): Observable<HttpResponse<CarePlan>>;
  public maternityCarePlanIdentifierPut(
    identifier: Uuidv4,
    body?: EditableCarePlan,
    observe?: 'events',
    reportProgress?: boolean
  ): Observable<HttpEvent<CarePlan>>;
  public maternityCarePlanIdentifierPut(
    identifier: Uuidv4,
    body?: EditableCarePlan,
    observe: any = 'body',
    reportProgress: boolean = false
  ): Observable<any> {
    if (identifier === null || identifier === undefined) {
      throw new Error('Required parameter identifier was null or undefined when calling maternityCarePlanIdentifierPut.');
    }

    let headers = this.defaultHeaders;

    // authentication (application) required
    if (this.configuration.accessToken) {
      const accessToken = typeof this.configuration.accessToken === 'function'
        ? this.configuration.accessToken()
        : this.configuration.accessToken;
      headers = headers.set('Authorization', 'Bearer ' + accessToken);
    }

    // to determine the Accept header
    const httpHeaderAccepts: string[] = [
      'application/json',
      'application/problem+json'
    ];
    const httpHeaderAcceptSelected: string | undefined = this.configuration.selectHeaderAccept(httpHeaderAccepts);
    if (!!httpHeaderAcceptSelected) {
      headers = headers.set('Accept', httpHeaderAcceptSelected);
    }

    // to determine the Content-Type header
    const consumes: string[] = [
      'application/json'
    ];
    const httpContentTypeSelected: string | undefined = this.configuration.selectHeaderContentType(consumes);
    if (!!httpContentTypeSelected) {
      headers = headers.set('Content-Type', httpContentTypeSelected);
    }

    return this.httpClient.put(`${this.basePath}/maternity/care-plan/${encodeURIComponent(String(identifier))}`,
      {
        withCredentials: this.configuration.withCredentials,
        headers,
        observe,
        reportProgress
      }
    );
  }

 /*
   * Create a care plan
   * Creates a new care plan for the current patient (which is stored in the session and can be updated using PUT on
   * the /patientcontext endpoint).
   * @param context The context encoded as a JWT token, see [SessionContext](#/components/schemas/SessionContext)
   * @param body the care-plan you want to create
   * @param xChosenRole The chosen user STS or SEB
   * @param xBreakTheGlassReason When set disables access controls for a well defined period of time or until the patient is changed
   * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
   * @param reportProgress flag to report request and response progress.
   */
  public maternityCarePlanPost(
    context: ApplicationContext,
    body?: EditableCarePlan,
    xChosenRole?: UserRole,
    xBreakTheGlassReason?: BreakTheGlassReason,
    observe?: 'body',
    reportProgress?: boolean
  ): Observable<CarePlan>;
  public maternityCarePlanPost(
    context: ApplicationContext,
    body?: EditableCarePlan,
    xChosenRole?: UserRole,
    xBreakTheGlassReason?: BreakTheGlassReason,
    observe?: 'response',
    reportProgress?: boolean
  ): Observable<HttpResponse<CarePlan>>;
  public maternityCarePlanPost(
    context: ApplicationContext,
    body?: EditableCarePlan,
    xChosenRole?: UserRole,
    xBreakTheGlassReason?: BreakTheGlassReason,
    observe?: 'events',
    reportProgress?: boolean
  ): Observable<HttpEvent<CarePlan>>;
  public maternityCarePlanPost(
    context: ApplicationContext,
    body?: EditableCarePlan,
    xChosenRole?: UserRole,
    xBreakTheGlassReason?: BreakTheGlassReason,
    observe: any = 'body',
    reportProgress: boolean = false
  ): Observable<any> {
    if (context === null || context === undefined) {
      throw new Error('Required parameter context was null or undefined when calling maternityCarePlanPost.');
    }

    let headers = this.defaultHeaders;
    if (xChosenRole !== undefined && xChosenRole !== null) {
      headers = headers.set('X-Chosen-Role', String(xChosenRole));
    }
    if (xBreakTheGlassReason !== undefined && xBreakTheGlassReason !== null) {
      headers = headers.set('X-Break-The-Glass-Reason', String(xBreakTheGlassReason));
    }

    // authentication (application) required
    if (this.configuration.accessToken) {
      const accessToken = typeof this.configuration.accessToken === 'function'
        ? this.configuration.accessToken()
        : this.configuration.accessToken;
      headers = headers.set('Authorization', 'Bearer ' + accessToken);
    }

    // to determine the Accept header
    const httpHeaderAccepts: string[] = [
      'application/json',
      'application/problem+json'
    ];
    const httpHeaderAcceptSelected: string | undefined = this.configuration.selectHeaderAccept(httpHeaderAccepts);
    if (!!httpHeaderAcceptSelected) {
      headers = headers.set('Accept', httpHeaderAcceptSelected);
    }

    // to determine the Content-Type header
    const consumes: string[] = [
      'application/json'
    ];
    const httpContentTypeSelected: string | undefined = this.configuration.selectHeaderContentType(consumes);
    if (!!httpContentTypeSelected) {
      headers = headers.set('Content-Type', httpContentTypeSelected);
    }

    return this.httpClient.post(`${this.basePath}/maternity/care-plan`,
      {
        withCredentials: this.configuration.withCredentials,
        headers,
        observe,
        reportProgress
      }
    );
  }

 /*
   * Get a template with a default care plan
   * Gets a default care plan containing the recommended activities etc. Post result of this back to
   * **_/maternity/care-plan** to create a care plan
   * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
   * @param reportProgress flag to report request and response progress.
   */
  public maternityCarePlanTemplateGet(observe?: 'body', reportProgress?: boolean): Observable<EditableCarePlan>;
  public maternityCarePlanTemplateGet(observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<EditableCarePlan>>;
  public maternityCarePlanTemplateGet(observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<EditableCarePlan>>;
  public maternityCarePlanTemplateGet(observe: any = 'body', reportProgress: boolean = false): Observable<any> {

    let headers = this.defaultHeaders;

    // authentication (application) required
    if (this.configuration.accessToken) {
      const accessToken = typeof this.configuration.accessToken === 'function'
        ? this.configuration.accessToken()
        : this.configuration.accessToken;
      headers = headers.set('Authorization', 'Bearer ' + accessToken);
    }

    // to determine the Accept header
    const httpHeaderAccepts: string[] = [
      'application/json'
    ];
    const httpHeaderAcceptSelected: string | undefined = this.configuration.selectHeaderAccept(httpHeaderAccepts);
    if (!!httpHeaderAcceptSelected) {
      headers = headers.set('Accept', httpHeaderAcceptSelected);
    }

    // to determine the Content-Type header
    const consumes: string[] = [];

    return this.httpClient.get(`${this.basePath}/maternity/care-plan/template`,
      {
        withCredentials: this.configuration.withCredentials,
        headers,
        observe,
        reportProgress
      }
    );
  }
}
