/**
 * DK Maternity Facade API
 * This is the specification of the DK Maternity Facade API. It is a facade for the Web Services Resource Transfer DK Maternity API.
 *
 * OpenAPI spec version: 1.0.0
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */

import { Inject, Injectable, Optional } from '@angular/core';
import { HttpClient, HttpHeaders, HttpParams,
 HttpResponse, HttpEvent } from '@angular/common/http';
import { CustomHttpUrlEncodingCodec } from '../encoder';

import {Observable} from 'rxjs';

import { ApplicationContext } from '../model/applicationContext';
import { BreakTheGlassReason } from '../model/breakTheGlassReason';
import { DataCardResponse } from '../model/dataCardResponse';
import { ProblemDetails } from '../model/problemDetails';
import { UserRole } from '../model/userRole';
import { Uuidv4 } from '../model/uuidv4';

import { BASE_PATH, COLLECTION_FORMATS } from '../variables';
import { Configuration } from '../configuration';
import {DataCardRequest} from '../model/dataCardRequest';


@Injectable()
export class DataCardService {

    protected basePath = '/';
    public defaultHeaders = new HttpHeaders();
    public configuration = new Configuration();

    constructor(
      protected httpClient: HttpClient,
      @Optional()@Inject(BASE_PATH) basePath: string,
      @Optional() configuration: Configuration
    ) {
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }

   /*
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm(consumes: string[]): boolean {
        const form = 'multipart/form-data';
        for (const consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }


   /*
     * Get data cards
     * Gets all data cards for the current patient (which is stored in the session and can be updated using PUT on the
     * /patientcontext endpoint)
     * @param context The context encoded as a JWT token, see [ApplicationContext](#/components/schemas/ApplicationContext)
     * @param xChosenRole The chosen user STS or SEB
     * @param xBreakTheGlassReason When set disables access controls for a well defined period of time or until the patient is changed
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    public maternityDataCardGet(
      context: ApplicationContext,
      xChosenRole?: UserRole,
      xBreakTheGlassReason?: BreakTheGlassReason,
      observe?: 'body',
      reportProgress?: boolean): Observable<Array<DataCardResponse>>;
    public maternityDataCardGet(
      context: ApplicationContext,
      xChosenRole?: UserRole,
      xBreakTheGlassReason?: BreakTheGlassReason,
      observe?: 'response',
      reportProgress?: boolean): Observable<HttpResponse<Array<DataCardResponse>>>;
    public maternityDataCardGet(
      context: ApplicationContext,
      xChosenRole?: UserRole,
      xBreakTheGlassReason?: BreakTheGlassReason,
      observe?: 'events',
      reportProgress?: boolean): Observable<HttpEvent<Array<DataCardResponse>>>;
    public maternityDataCardGet(
      context: ApplicationContext,
      xChosenRole?: UserRole,
      xBreakTheGlassReason?: BreakTheGlassReason,
      observe: any = 'body',
      reportProgress: boolean = false ): Observable<any> {
        if (context === null || context === undefined) {
            throw new Error('Required parameter context was null or undefined when calling maternityDataCardGet.');
        }

        let headers = this.defaultHeaders;
        if (xChosenRole !== undefined && xChosenRole !== null) {
            headers = headers.set('X-Chosen-Role', String(xChosenRole));
        }
        if (xBreakTheGlassReason !== undefined && xBreakTheGlassReason !== null) {
            headers = headers.set('X-Break-The-Glass-Reason', String(xBreakTheGlassReason));
        }

        // authentication (application) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }

        // to determine the Accept header
        const httpHeaderAccepts: string[] = [
            'application/json',
            'application/problem+json'
        ];
        const httpHeaderAcceptSelected: string | undefined = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (!!httpHeaderAcceptSelected) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }

        // to determine the Content-Type header
        const consumes: string[] = [
        ];

        return this.httpClient.get(`${this.basePath}/maternity/data-card`,
            {
                withCredentials: this.configuration.withCredentials,
                headers,
                observe,
                reportProgress
            }
        );
    }

   /*
     * Delete a specific data card
     *
     * @param identifier The identifier of the data card
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    public maternityDataCardIdentifierDelete(
      identifier: Uuidv4,
      observe?: 'body',
      reportProgress?: boolean): Observable<any>;
    public maternityDataCardIdentifierDelete(
      identifier: Uuidv4,
      observe?: 'response',
      reportProgress?: boolean): Observable<HttpResponse<any>>;
    public maternityDataCardIdentifierDelete(
      identifier: Uuidv4,
      observe?: 'events',
      reportProgress?: boolean): Observable<HttpEvent<any>>;
    public maternityDataCardIdentifierDelete(
      identifier: Uuidv4,
      observe: any = 'body',
      reportProgress: boolean = false ): Observable<any> {
        if (identifier === null || identifier === undefined) {
            throw new Error('Required parameter identifier was null or undefined when calling maternityDataCardIdentifierDelete.');
        }

        let headers = this.defaultHeaders;

        // authentication (application) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }

        // to determine the Accept header
        const httpHeaderAccepts: string[] = [
            'application/problem+json'
        ];
        const httpHeaderAcceptSelected: string | undefined = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }

        // to determine the Content-Type header
        const consumes: string[] = [
        ];

        return this.httpClient.delete(`${this.basePath}/maternity/data-card/${encodeURIComponent(String(identifier))}`,
            {
                withCredentials: this.configuration.withCredentials,
                headers,
                observe,
                reportProgress
            }
        );
    }

   /*
     * Get a specific data card
     *
     * @param identifier The identifier of the data card
     * @param xBreakTheGlassReason When set disables access controls for a well defined period of time or until the patient is changed
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    public maternityDataCardIdentifierGet(
      identifier: Uuidv4,
      xBreakTheGlassReason?: BreakTheGlassReason,
      observe?: 'body',
      reportProgress?: boolean): Observable<DataCardResponse>;
    public maternityDataCardIdentifierGet(
      identifier: Uuidv4,
      xBreakTheGlassReason?: BreakTheGlassReason,
      observe?: 'response',
      reportProgress?: boolean): Observable<HttpResponse<DataCardResponse>>;
    public maternityDataCardIdentifierGet(
      identifier: Uuidv4,
      xBreakTheGlassReason?: BreakTheGlassReason,
      observe?: 'events',
      reportProgress?: boolean): Observable<HttpEvent<DataCardResponse>>;
    public maternityDataCardIdentifierGet(
      identifier: Uuidv4,
      xBreakTheGlassReason?: BreakTheGlassReason,
      observe: any = 'body',
      reportProgress: boolean = false ): Observable<any> {
        if (identifier === null || identifier === undefined) {
            throw new Error('Required parameter identifier was null or undefined when calling maternityDataCardIdentifierGet.');
        }

        let headers = this.defaultHeaders;
        if (xBreakTheGlassReason !== undefined && xBreakTheGlassReason !== null) {
            headers = headers.set('X-Break-The-Glass-Reason', String(xBreakTheGlassReason));
        }

        // authentication (application) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }

        // to determine the Accept header
        const httpHeaderAccepts: string[] = [
            'application/json',
            'application/problem+json'
        ];
        const httpHeaderAcceptSelected: string | undefined = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }

        // to determine the Content-Type header
        const consumes: string[] = [
        ];

        return this.httpClient.get(`${this.basePath}/maternity/data-card/${encodeURIComponent(String(identifier))}`,
            {
                withCredentials: this.configuration.withCredentials,
                headers,
                observe,
                reportProgress
            }
        );
    }

   /*
     * Update a specific data card
     *
     * @param identifier The identifier of the data card
     * @param body the data-cad to update
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    public maternityDataCardIdentifierPut(
      identifier: Uuidv4,
      body?: DataCardRequest,
      observe?: 'body',
      reportProgress?: boolean): Observable<DataCardResponse>;
    public maternityDataCardIdentifierPut(
      identifier: Uuidv4,
      body?: DataCardRequest,
      observe?: 'response',
      reportProgress?: boolean): Observable<HttpResponse<DataCardResponse>>;
    public maternityDataCardIdentifierPut(
      identifier: Uuidv4,
      body?: DataCardRequest,
      observe?: 'events',
      reportProgress?: boolean): Observable<HttpEvent<DataCardResponse>>;
    public maternityDataCardIdentifierPut(
      identifier: Uuidv4,
      body?: DataCardRequest,
      observe: any = 'body',
      reportProgress: boolean = false ): Observable<any> {
        if (identifier === null || identifier === undefined) {
            throw new Error('Required parameter identifier was null or undefined when calling maternityDataCardIdentifierPut.');
        }

        let headers = this.defaultHeaders;

        // authentication (application) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }

        // to determine the Accept header
        const httpHeaderAccepts: string[] = [
            'application/json',
            'application/problem+json'
        ];
        const httpHeaderAcceptSelected: string | undefined = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }

        // to determine the Content-Type header
        const consumes: string[] = [
            'application/json'
        ];
        const httpContentTypeSelected: string | undefined = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }

        return this.httpClient.put(`${this.basePath}/maternity/data-card/${encodeURIComponent(String(identifier))}`,
            {
                withCredentials: this.configuration.withCredentials,
                headers,
                observe,
                reportProgress
            }
        );
    }

   /*
     * Create a data card
     * Creates a new data card for the current patient (which is stored in the session and can be updated using PUT on the /patientcontext endpoint)
     * @param context The context encoded as a JWT token, see [ApplicationContext](#/components/schemas/ApplicationContext)
     * @param body the data-card to create
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    public maternityDataCardPost(
      context: ApplicationContext,
      body?: DataCardRequest,
      observe?: 'body',
      reportProgress?: boolean): Observable<DataCardResponse>;
    public maternityDataCardPost(
      context: ApplicationContext,
      body?: DataCardRequest,
      observe?: 'response',
      reportProgress?: boolean): Observable<HttpResponse<DataCardResponse>>;
    public maternityDataCardPost(
      context: ApplicationContext,
      body?: DataCardRequest,
      observe?: 'events',
      reportProgress?: boolean): Observable<HttpEvent<DataCardResponse>>;
    public maternityDataCardPost(
      context: ApplicationContext,
      body?: DataCardRequest,
      observe: any = 'body',
      reportProgress: boolean = false ): Observable<any> {
        if (context === null || context === undefined) {
            throw new Error('Required parameter context was null or undefined when calling maternityDataCardPost.');
        }

        let headers = this.defaultHeaders;

        // authentication (application) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }

        // to determine the Accept header
        const httpHeaderAccepts: string[] = [
            'application/json',
            'application/problem+json'
        ];
        const httpHeaderAcceptSelected: string | undefined = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }

        // to determine the Content-Type header
        const consumes: string[] = [
            'application/json'
        ];
        const httpContentTypeSelected: string | undefined = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }

        return this.httpClient.post(`${this.basePath}/maternity/data-card`,
            {
                withCredentials: this.configuration.withCredentials,
                headers,
                observe,
                reportProgress
            }
        );
    }

}
