/**
 * DK Maternity Facade API
 * This is the specification of the DK Maternity Facade API. It is a facade for the Web Services Resource Transfer DK Maternity API.
 *
 * OpenAPI spec version: 1.0.0
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */

import { Inject, Injectable, Optional } from '@angular/core';
import { HttpClient, HttpHeaders, HttpParams,
 HttpResponse, HttpEvent } from '@angular/common/http';
import { CustomHttpUrlEncodingCodec } from '../encoder';

import { Observable } from 'rxjs';

import { ApplicationContext } from '../model/applicationContext';
import { BreakTheGlassReason } from '../model/breakTheGlassReason';
import { EditableNote } from '../model/editableNote';
import { Note } from '../model/note';
import { UserRole } from '../model/userRole';

import { BASE_PATH, COLLECTION_FORMATS } from '../variables';
import { Configuration } from '../configuration';


@Injectable()
export class NoteService {

  protected basePath = '/';
  public defaultHeaders = new HttpHeaders();
  public configuration = new Configuration();

  constructor(
    protected httpClient: HttpClient,
    @Optional() @Inject(BASE_PATH) basePath: string,
    @Optional() configuration: Configuration
  ) {
    if (basePath) {
      this.basePath = basePath;
    }
    if (configuration) {
      this.configuration = configuration;
      this.basePath = basePath || configuration.basePath || this.basePath;
    }
  }

  /**
   * @param consumes string[] mime-types
   * @return true: consumes contains 'multipart/form-data', false: otherwise
   */
  private canConsumeForm(consumes: string[]): boolean {
    const form = 'multipart/form-data';
    for (const consume of consumes) {
      if (form === consume) {
        return true;
      }
    }
    return false;
  }


  /**
   * Get notes
   * Gets all notes for the current patient ((which is stored in the session and can be updated using PUT on the /patientcontext endpoint)
   * @param context The context encoded as a JWT token, see [SessionContext](#/components/schemas/SessionContext)
   * @param xChosenRole The chosen user STS or SEB
   * @param xBreakTheGlassReason When set disables access controls for a well defined period of time or until the patient is changed
   * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
   * @param reportProgress flag to report request and response progress.
   */
  public maternityNoteGet(
    context: ApplicationContext,
    xChosenRole?: UserRole,
    xBreakTheGlassReason?: BreakTheGlassReason,
    observe?: 'body',
    reportProgress?: boolean): Observable<Array<Note>>;
  public maternityNoteGet(
    context: ApplicationContext,
    xChosenRole?: UserRole,
    xBreakTheGlassReason?: BreakTheGlassReason,
    observe?: 'response',
    reportProgress?: boolean): Observable<HttpResponse<Array<Note>>>;
  public maternityNoteGet(
    context: ApplicationContext,
    xChosenRole?: UserRole,
    xBreakTheGlassReason?: BreakTheGlassReason,
    observe?: 'events',
    reportProgress?: boolean): Observable<HttpEvent<Array<Note>>>;
  public maternityNoteGet(
    context: ApplicationContext,
    xChosenRole?: UserRole,
    xBreakTheGlassReason?: BreakTheGlassReason,
    observe: any = 'body',
    reportProgress: boolean = false): Observable<any> {
    if (context === null || context === undefined) {
      throw new Error('Required parameter context was null or undefined when calling maternityNoteGet.');
    }

    let headers = this.defaultHeaders;
    if (xChosenRole !== undefined && xChosenRole !== null) {
      headers = headers.set('X-Chosen-Role', String(xChosenRole));
    }
    if (xBreakTheGlassReason !== undefined && xBreakTheGlassReason !== null) {
      headers = headers.set('X-Break-The-Glass-Reason', String(xBreakTheGlassReason));
    }

    // authentication (application) required
    if (this.configuration.accessToken) {
      const accessToken = typeof this.configuration.accessToken === 'function'
        ? this.configuration.accessToken()
        : this.configuration.accessToken;
      headers = headers.set('Authorization', 'Bearer ' + accessToken);
    }

    // to determine the Accept header
    const httpHeaderAccepts: string[] = [
      'application/json',
      'application/problem+json'
    ];
    const httpHeaderAcceptSelected: string | undefined = this.configuration.selectHeaderAccept(httpHeaderAccepts);
    if (httpHeaderAcceptSelected) {
      headers = headers.set('Accept', httpHeaderAcceptSelected);
    }

    // to determine the Content-Type header
    const consumes: string[] = [];

    return this.httpClient.get(`${this.basePath}/maternity/note`,
      {
        withCredentials: this.configuration.withCredentials,
        headers,
        observe,
        reportProgress
      }
    );
  }

  /**
   * Get the note with the specified **identifier**
   * Gets the note with the **identifier** specified in the URI, provided it belongs to the current patient
   * (which is stored in the session and can be updated using PUT on the /patientcontext endpoint)
   * @param identifier The identifier of the note
   * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
   * @param reportProgress flag to report request and response progress.
   */
  public maternityNoteIdentifierGet(identifier: string, observe?: 'body', reportProgress?: boolean): Observable<Note>;
  public maternityNoteIdentifierGet(identifier: string, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Note>>;
  public maternityNoteIdentifierGet(identifier: string, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Note>>;
  public maternityNoteIdentifierGet(identifier: string, observe: any = 'body', reportProgress: boolean = false): Observable<any> {
    if (identifier === null || identifier === undefined) {
      throw new Error('Required parameter identifier was null or undefined when calling maternityNoteIdentifierGet.');
    }

    let headers = this.defaultHeaders;

    // authentication (application) required
    if (this.configuration.accessToken) {
      const accessToken = typeof this.configuration.accessToken === 'function'
        ? this.configuration.accessToken()
        : this.configuration.accessToken;
      headers = headers.set('Authorization', 'Bearer ' + accessToken);
    }

    // to determine the Accept header
    const httpHeaderAccepts: string[] = [
      'application/json',
      'application/problem+json'
    ];
    const httpHeaderAcceptSelected: string | undefined = this.configuration.selectHeaderAccept(httpHeaderAccepts);
    if (httpHeaderAcceptSelected) {
      headers = headers.set('Accept', httpHeaderAcceptSelected);
    }

    // to determine the Content-Type header
    const consumes: string[] = [];

    return this.httpClient.get(`${this.basePath}/maternity/note/${encodeURIComponent(String(identifier))}`,
      {
        withCredentials: this.configuration.withCredentials,
        headers,
        observe,
        reportProgress
      }
    );
  }

  /**
   * Update the note with the specified **identifier**
   * Updates the note with the **identifier** specified in the URI provided it belongs to the current patient
   * (which is stored in the session and can be updated using PUT on the /patientcontext endpoint).
   * @param identifier The identifier of the note
   * @param body the note to update
   * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
   * @param reportProgress flag to report request and response progress.
   */
  public maternityNoteIdentifierPut(
    identifier: string,
    body?: EditableNote,
    observe?: 'body',
    reportProgress?: boolean): Observable<Note>;
  public maternityNoteIdentifierPut(
    identifier: string,
    body?: EditableNote,
    observe?: 'response',
    reportProgress?: boolean): Observable<HttpResponse<Note>>;
  public maternityNoteIdentifierPut(
    identifier: string,
    body?: EditableNote,
    observe?: 'events',
    reportProgress?: boolean): Observable<HttpEvent<Note>>;
  public maternityNoteIdentifierPut(
    identifier: string,
    body?: EditableNote,
    observe: any = 'body',
    reportProgress: boolean = false): Observable<any> {
    if (identifier === null || identifier === undefined) {
      throw new Error('Required parameter identifier was null or undefined when calling maternityNoteIdentifierPut.');
    }

    let headers = this.defaultHeaders;

    // authentication (application) required
    if (this.configuration.accessToken) {
      const accessToken = typeof this.configuration.accessToken === 'function'
        ? this.configuration.accessToken()
        : this.configuration.accessToken;
      headers = headers.set('Authorization', 'Bearer ' + accessToken);
    }

    // to determine the Accept header
    const httpHeaderAccepts: string[] = [
      'application/json',
      'application/problem+json'
    ];
    const httpHeaderAcceptSelected: string | undefined = this.configuration.selectHeaderAccept(httpHeaderAccepts);
    if (httpHeaderAcceptSelected) {
      headers = headers.set('Accept', httpHeaderAcceptSelected);
    }

    // to determine the Content-Type header
    const consumes: string[] = [
      'application/json'
    ];
    const httpContentTypeSelected: string | undefined = this.configuration.selectHeaderContentType(consumes);
    if (httpContentTypeSelected) {
      headers = headers.set('Content-Type', httpContentTypeSelected);
    }

    return this.httpClient.put(`${this.basePath}/maternity/note/${encodeURIComponent(String(identifier))}`,
      {
        withCredentials: this.configuration.withCredentials,
        headers,
        observe,
        reportProgress
      }
    );
  }

  /**
   * Create a note
   * Creates a new note for the current patient (which is stored in the session and can be updated using PUT on the
   * /patientcontext endpoint).
   * Adds a reference to the activity referenced in the query param-
   * @param context The context encoded as a JWT token, see [SessionContext](#/components/schemas/SessionContext)
   * @param body The note to create
   * @param xChosenRole The chosen user STS or SEB
   * @param xBreakTheGlassReason When set disables access controls for a well defined period of time or until the patient is changed
   * @param activity The activity that this note is related to
   * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
   * @param reportProgress flag to report request and response progress.
   */
  public maternityNotePost(
    context: ApplicationContext,
    body?: EditableNote,
    xChosenRole?: UserRole,
    xBreakTheGlassReason?: BreakTheGlassReason,
    activity?: string,
    observe?: 'body',
    reportProgress?: boolean): Observable<Note>;
  public maternityNotePost(
    context: ApplicationContext,
    body?: EditableNote,
    xChosenRole?: UserRole,
    xBreakTheGlassReason?: BreakTheGlassReason,
    activity?: string,
    observe?: 'response',
    reportProgress?: boolean): Observable<HttpResponse<Note>>;
  public maternityNotePost(
    context: ApplicationContext,
    body?: EditableNote,
    xChosenRole?: UserRole,
    xBreakTheGlassReason?: BreakTheGlassReason,
    activity?: string,
    observe?: 'events',
    reportProgress?: boolean): Observable<HttpEvent<Note>>;
  public maternityNotePost(
    context: ApplicationContext,
    body?: EditableNote,
    xChosenRole?: UserRole,
    xBreakTheGlassReason?: BreakTheGlassReason,
    activity?: string,
    observe: any = 'body',
    reportProgress: boolean = false): Observable<any> {
    if (context === null || context === undefined) {
      throw new Error('Required parameter context was null or undefined when calling maternityNotePost.');
    }

    let queryParameters = new HttpParams({encoder: new CustomHttpUrlEncodingCodec()});
    if (activity) {
      queryParameters = queryParameters.set('activity', activity);
    }

    let headers = this.defaultHeaders;
    if (xChosenRole !== undefined && xChosenRole !== null) {
      headers = headers.set('X-Chosen-Role', String(xChosenRole));
    }
    if (xBreakTheGlassReason !== undefined && xBreakTheGlassReason !== null) {
      headers = headers.set('X-Break-The-Glass-Reason', String(xBreakTheGlassReason));
    }

    // authentication (application) required
    if (this.configuration.accessToken) {
      const accessToken = typeof this.configuration.accessToken === 'function'
        ? this.configuration.accessToken()
        : this.configuration.accessToken;
      headers = headers.set('Authorization', 'Bearer ' + accessToken);
    }

    // to determine the Accept header
    const httpHeaderAccepts: string[] = [
      'application/json',
      'application/problem+json'
    ];
    const httpHeaderAcceptSelected: string | undefined = this.configuration.selectHeaderAccept(httpHeaderAccepts);
    if (httpHeaderAcceptSelected) {
      headers = headers.set('Accept', httpHeaderAcceptSelected);
    }

    // to determine the Content-Type header
    const consumes: string[] = [
      'application/json'
    ];
    const httpContentTypeSelected: string | undefined = this.configuration.selectHeaderContentType(consumes);
    if (httpContentTypeSelected) {
      headers = headers.set('Content-Type', httpContentTypeSelected);
    }

    return this.httpClient.post(`${this.basePath}/maternity/note`,
      {
        params: queryParameters,
        withCredentials: this.configuration.withCredentials,
        headers,
        observe,
        reportProgress
      }
    );
  }
}
