/**
 * DK Maternity Facade API
 * This is the specification of the DK Maternity Facade API. It is a facade for the Web Services Resource Transfer DK Maternity API.
 *
 * OpenAPI spec version: 1.0.0
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */

import { Inject, Injectable, Optional } from '@angular/core';
import { HttpClient, HttpHeaders, HttpParams,
 HttpResponse, HttpEvent } from '@angular/common/http';
import { CustomHttpUrlEncodingCodec } from '../encoder';

import { Observable } from 'rxjs';

import { ApplicationContext } from '../model/applicationContext';
import { BreakTheGlassReason } from '../model/breakTheGlassReason';
import { EditableObservation } from '../model/editableObservation';
import { Observation } from '../model/observation';
import { ObservationType } from '../model/observationType';
import { ProblemDetails } from '../model/problemDetails';
import { UserRole } from '../model/userRole';

import { BASE_PATH, COLLECTION_FORMATS } from '../variables';
import { Configuration } from '../configuration';
import {CreateObservation} from '../model/createObservation';


@Injectable()
export class ObservationService {

  protected basePath = '/';
  public defaultHeaders = new HttpHeaders();
  public configuration = new Configuration();

  constructor(
    protected httpClient: HttpClient,
    @Optional() @Inject(BASE_PATH) basePath: string,
    @Optional() configuration: Configuration
  ) {
    if (basePath) {
      this.basePath = basePath;
    }
    if (configuration) {
      this.configuration = configuration;
      this.basePath = basePath || configuration.basePath || this.basePath;
    }
  }

 /*
   * @param consumes string[] mime-types
   * @return true: consumes contains 'multipart/form-data', false: otherwise
   */
  private canConsumeForm(consumes: string[]): boolean {
    const form = 'multipart/form-data';
    for (const consume of consumes) {
      if (form === consume) {
        return true;
      }
    }
    return false;
  }


 /*
   * Get observations
   * Gets all observations for the current patient (which is stored in the session and can be updated using PUT on the
   * /patientcontext endpoint), related to the currently active pregnancy.
   * @param context The context encoded as a JWT token, see [SessionContext](#/components/schemas/SessionContext)
   * @param xChosenRole The chosen user STS or SEB
   * @param xBreakTheGlassReason When set disables access controls for a well defined period of time or until the patient is changed
   * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
   * @param reportProgress flag to report request and response progress.
   */
  public maternityObservationGet(
    context: ApplicationContext,
    xChosenRole?: UserRole,
    xBreakTheGlassReason?: BreakTheGlassReason,
    observe?: 'body',
    reportProgress?: boolean): Observable<Array<Observation>>;
  public maternityObservationGet(
    context: ApplicationContext,
    xChosenRole?: UserRole,
    xBreakTheGlassReason?: BreakTheGlassReason,
    observe?: 'response',
    reportProgress?: boolean): Observable<HttpResponse<Array<Observation>>>;
  public maternityObservationGet(
    context: ApplicationContext,
    xChosenRole?: UserRole,
    xBreakTheGlassReason?: BreakTheGlassReason,
    observe?: 'events',
    reportProgress?: boolean): Observable<HttpEvent<Array<Observation>>>;
  public maternityObservationGet(
    context: ApplicationContext,
    xChosenRole?: UserRole,
    xBreakTheGlassReason?: BreakTheGlassReason,
    observe: any = 'body',
    reportProgress: boolean = false): Observable<any> {
    if (context === null || context === undefined) {
      throw new Error('Required parameter context was null or undefined when calling maternityObservationGet.');
    }

    let headers = this.defaultHeaders;
    if (xChosenRole !== undefined && xChosenRole !== null) {
      headers = headers.set('X-Chosen-Role', String(xChosenRole));
    }
    if (xBreakTheGlassReason !== undefined && xBreakTheGlassReason !== null) {
      headers = headers.set('X-Break-The-Glass-Reason', String(xBreakTheGlassReason));
    }

    // authentication (application) required
    if (this.configuration.accessToken) {
      const accessToken = typeof this.configuration.accessToken === 'function'
        ? this.configuration.accessToken()
        : this.configuration.accessToken;
      headers = headers.set('Authorization', 'Bearer ' + accessToken);
    }

    // to determine the Accept header
    const httpHeaderAccepts: string[] = [
      'application/json',
      'application/problem+json'
    ];
    const httpHeaderAcceptSelected: string | undefined = this.configuration.selectHeaderAccept(httpHeaderAccepts);
    if (httpHeaderAcceptSelected) {
      headers = headers.set('Accept', httpHeaderAcceptSelected);
    }

    // to determine the Content-Type header
    const consumes: string[] = [];

    return this.httpClient.get(`${this.basePath}/maternity/observation`,
      {
        withCredentials: this.configuration.withCredentials,
        headers,
        observe,
        reportProgress
      }
    );
  }

 /*
   * Get the observation with the specified **identifier**
   * Gets the observation with the **identifier** specified in the URI provided it belongs to the current patient
   * (which is stored in the session and can be updated using PUT on the /patientcontext endpoint).
   * @param identifier The identifier of the observation
   * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
   * @param reportProgress flag to report request and response progress.
   */
  public maternityObservationIdentifierGet(
    identifier: string,
    observe?: 'body',
    reportProgress?: boolean): Observable<Observation>;
  public maternityObservationIdentifierGet(
    identifier: string,
    observe?: 'response',
    reportProgress?: boolean): Observable<HttpResponse<Observation>>;
  public maternityObservationIdentifierGet(
    identifier: string,
    observe?: 'events',
    reportProgress?: boolean): Observable<HttpEvent<Observation>>;
  public maternityObservationIdentifierGet(
    identifier: string,
    observe: any = 'body',
    reportProgress: boolean = false): Observable<any> {
    if (identifier === null || identifier === undefined) {
      throw new Error('Required parameter identifier was null or undefined when calling maternityObservationIdentifierGet.');
    }

    let headers = this.defaultHeaders;

    // authentication (application) required
    if (this.configuration.accessToken) {
      const accessToken = typeof this.configuration.accessToken === 'function'
        ? this.configuration.accessToken()
        : this.configuration.accessToken;
      headers = headers.set('Authorization', 'Bearer ' + accessToken);
    }

    // to determine the Accept header
    const httpHeaderAccepts: string[] = [
      'application/json',
      'application/problem+json'
    ];
    const httpHeaderAcceptSelected: string | undefined = this.configuration.selectHeaderAccept(httpHeaderAccepts);
    if (httpHeaderAcceptSelected) {
      headers = headers.set('Accept', httpHeaderAcceptSelected);
    }

    // to determine the Content-Type header
    const consumes: string[] = [];

    return this.httpClient.get(`${this.basePath}/maternity/observation/${encodeURIComponent(String(identifier))}`,
      {
        withCredentials: this.configuration.withCredentials,
        headers,
        observe,
        reportProgress
      }
    );
  }

 /*
   * Update the observation with the specified **identifier**
   * Updates the observation with the **identifier** specified in the URI provided it belongs to the current patient
   * (which is stored in the session and can be updated using PUT on the /patientcontext endpoint).
   * @param identifier The identifier of the observation
   * @param body the observation to edit
   * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
   * @param reportProgress flag to report request and response progress.
   */
  public maternityObservationIdentifierPut(
    identifier: string,
    body?: EditableObservation,
    observe?: 'body',
    reportProgress?: boolean): Observable<Observation>;
  public maternityObservationIdentifierPut(
    identifier: string,
    body?: EditableObservation,
    observe?: 'response',
    reportProgress?: boolean): Observable<HttpResponse<Observation>>;
  public maternityObservationIdentifierPut(
    identifier: string,
    body?: EditableObservation,
    observe?: 'events',
    reportProgress?: boolean): Observable<HttpEvent<Observation>>;
  public maternityObservationIdentifierPut(
    identifier: string,
    body?: EditableObservation,
    observe: any = 'body',
    reportProgress: boolean = false): Observable<any> {
    if (identifier === null || identifier === undefined) {
      throw new Error('Required parameter identifier was null or undefined when calling maternityObservationIdentifierPut.');
    }

    let headers = this.defaultHeaders;

    // authentication (application) required
    if (this.configuration.accessToken) {
      const accessToken = typeof this.configuration.accessToken === 'function'
        ? this.configuration.accessToken()
        : this.configuration.accessToken;
      headers = headers.set('Authorization', 'Bearer ' + accessToken);
    }

    // to determine the Accept header
    const httpHeaderAccepts: string[] = [
      'application/json',
      'application/problem+json'
    ];
    const httpHeaderAcceptSelected: string | undefined = this.configuration.selectHeaderAccept(httpHeaderAccepts);
    if (httpHeaderAcceptSelected) {
      headers = headers.set('Accept', httpHeaderAcceptSelected);
    }

    // to determine the Content-Type header
    const consumes: string[] = [
      'application/json'
    ];
    const httpContentTypeSelected: string | undefined = this.configuration.selectHeaderContentType(consumes);
    if (httpContentTypeSelected) {
      headers = headers.set('Content-Type', httpContentTypeSelected);
    }

    return this.httpClient.put(`${this.basePath}/maternity/observation/${encodeURIComponent(String(identifier))}`,
      {
        withCredentials: this.configuration.withCredentials,
        headers,
        observe,
        reportProgress
      }
    );
  }

 /*
   * Create an observation
   * Creates a new observation for the current patient (which is stored in the session and can be updated using PUT on
   * the /patientcontext endpoint) as part of the currently active pregnency.
   * @param context The context encoded as a JWT token, see [SessionContext](#/components/schemas/SessionContext)
   * @param body the observation to create
   * @param xChosenRole The chosen user STS or SEB
   * @param xBreakTheGlassReason When set disables access controls for a well defined period of time or until the patient is changed
   * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
   * @param reportProgress flag to report request and response progress.
   */
  public maternityObservationPost(
    context: ApplicationContext,
    body?: CreateObservation,
    xChosenRole?: UserRole,
    xBreakTheGlassReason?: BreakTheGlassReason,
    observe?: 'body',
    reportProgress?: boolean): Observable<Observation>;
  public maternityObservationPost(
    context: ApplicationContext,
    body?: CreateObservation,
    xChosenRole?: UserRole,
    xBreakTheGlassReason?: BreakTheGlassReason,
    observe?: 'response',
    reportProgress?: boolean): Observable<HttpResponse<Observation>>;
  public maternityObservationPost(
    context: ApplicationContext,
    body?: CreateObservation,
    xChosenRole?: UserRole,
    xBreakTheGlassReason?: BreakTheGlassReason,
    observe?: 'events',
    reportProgress?: boolean): Observable<HttpEvent<Observation>>;
  public maternityObservationPost(
    context: ApplicationContext,
    body?: CreateObservation,
    xChosenRole?: UserRole,
    xBreakTheGlassReason?: BreakTheGlassReason,
    observe: any = 'body',
    reportProgress: boolean = false): Observable<any> {
    if (context === null || context === undefined) {
      throw new Error('Required parameter context was null or undefined when calling maternityObservationPost.');
    }

    let headers = this.defaultHeaders;
    if (xChosenRole !== undefined && xChosenRole !== null) {
      headers = headers.set('X-Chosen-Role', String(xChosenRole));
    }
    if (xBreakTheGlassReason !== undefined && xBreakTheGlassReason !== null) {
      headers = headers.set('X-Break-The-Glass-Reason', String(xBreakTheGlassReason));
    }

    // authentication (application) required
    if (this.configuration.accessToken) {
      const accessToken = typeof this.configuration.accessToken === 'function'
        ? this.configuration.accessToken()
        : this.configuration.accessToken;
      headers = headers.set('Authorization', 'Bearer ' + accessToken);
    }

    // to determine the Accept header
    const httpHeaderAccepts: string[] = [
      'application/json',
      'application/problem+json'
    ];
    const httpHeaderAcceptSelected: string | undefined = this.configuration.selectHeaderAccept(httpHeaderAccepts);
    if (httpHeaderAcceptSelected) {
      headers = headers.set('Accept', httpHeaderAcceptSelected);
    }

    // to determine the Content-Type header
    const consumes: string[] = [
      'application/json'
    ];
    const httpContentTypeSelected: string | undefined = this.configuration.selectHeaderContentType(consumes);
    if (httpContentTypeSelected) {
      headers = headers.set('Content-Type', httpContentTypeSelected);
    }

    return this.httpClient.post(`${this.basePath}/maternity/observation`,
      {
        withCredentials: this.configuration.withCredentials,
        headers,
        observe,
        reportProgress
      }
    );
  }

 /*
   * Get the list of allowed observation types
   * Get the list of allowed observation types which can be used when creating observations
   * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
   * @param reportProgress flag to report request and response progress.
   */
  public maternityObservationTypeGet(observe?: 'body', reportProgress?: boolean): Observable<ObservationType>;
  public maternityObservationTypeGet(observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<ObservationType>>;
  public maternityObservationTypeGet(observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<ObservationType>>;
  public maternityObservationTypeGet(observe: any = 'body', reportProgress: boolean = false): Observable<any> {

    let headers = this.defaultHeaders;

    // authentication (application) required
    if (this.configuration.accessToken) {
      const accessToken = typeof this.configuration.accessToken === 'function'
        ? this.configuration.accessToken()
        : this.configuration.accessToken;
      headers = headers.set('Authorization', 'Bearer ' + accessToken);
    }

    // to determine the Accept header
    const httpHeaderAccepts: string[] = [
      'application/json',
      'application/problem+json'
    ];
    const httpHeaderAcceptSelected: string | undefined = this.configuration.selectHeaderAccept(httpHeaderAccepts);
    if (httpHeaderAcceptSelected) {
      headers = headers.set('Accept', httpHeaderAcceptSelected);
    }

    // to determine the Content-Type header
    const consumes: string[] = [];

    return this.httpClient.get(`${this.basePath}/maternity/observation/type`,
      {
        withCredentials: this.configuration.withCredentials,
        headers,
        observe,
        reportProgress
      }
    );
  }
}
