import {Component, ElementRef, ViewChild} from '@angular/core';
import {Observable} from 'rxjs';
import {ActivitiesService, FakeDataCard} from './activities.service';
import {animate, style, transition, trigger} from '@angular/animations';
import {ActivityModalComponent} from './activity-modal/activity-modal.component';
import {Activity} from "facade-api";

@Component({
  selector: 'app-activities',
  templateUrl: './activities.component.html',
  styleUrls: ['./activities.component.scss'],
  animations: [
    trigger(
      'inOutAnimation',
      [
        transition(
          ':enter',
          [
            style({ opacity: 0 }),
            animate('0.5s ease-out',
              style({opacity: 1 }))
          ]
        ),
        transition(
          ':leave',
          [
            style({ opacity: 1 })
          ]
        )
      ]
    )
  ]
})
export class ActivitiesComponent {

  public pastActivities$: Observable<Activity[]> =  this.activitiesService.pastActivities$;
  public futureActivities: Observable<Activity[]> =  this.activitiesService.futureActivities$;
  public dummyDataCard$: Observable<FakeDataCard> =  this.activitiesService.dummyDataCard$;
  public dividerPassed = false;
  @ViewChild('divider') public divider: ElementRef | undefined;
  @ViewChild('activityModal') public activityModal: ActivityModalComponent | undefined;
  constructor(private activitiesService: ActivitiesService) {
  }

  public onScroll($event: Event): void {
    if (this.divider) {
      const container = $event.target as HTMLDivElement;
      const elementPosition = this.divider.nativeElement.offsetTop;
      const scrollPosition = container.scrollTop + container.offsetTop;
      this.dividerPassed = scrollPosition >= elementPosition;
    }
  }
}
