import {Injectable} from '@angular/core';
import {Observable} from 'rxjs';
import {map} from 'rxjs/operators';
import {DataSourceService} from '../services/data-source.service';
import {Activity} from 'facade-api';

export interface FakeDataCard {
    CareLevel: string;
    gestationAge: string;
    term: string;
    multiple: string;
    Parity: string;
    conditions: string;
    translationAssistance: string;
    smokingStatus: string;
}

@Injectable({providedIn: 'root'})
export class ActivitiesService {
  constructor(private dataSourceService: DataSourceService) { }
  public dummyDataCard$: Observable<FakeDataCard> = this.dataSourceService.dummyDataCards$.pipe(
    map(dataCards => {
      return {
        CareLevel: '4',
        gestationAge: '22+1 uger',
        term: '05-11-2020',
        multiple: 'Ja',
        Parity: '0',
        conditions: 'Diabetes +',
        translationAssistance: 'Ja',
        smokingStatus: 'Ja'
      };
    }));
  private activities$: Observable<Activity[]> = this.dataSourceService.carePlan$.pipe(
    map(carePlans => carePlans[0].activities ?? []),
  );

  public futureActivities$: Observable<Activity[]> = this.activities$.pipe(
    map(activities => activities.filter(activity => !activity.plannedTime?.from || activity.plannedTime.from >= new Date()))
  );

  public pastActivities$: Observable<Activity[]> = this.activities$.pipe(
    map(activities => activities.filter(activity => activity.plannedTime?.from && activity.plannedTime.from < new Date()))
  );
}
