import {Component, Input, OnInit} from '@angular/core';
import {animate, style, transition, trigger} from '@angular/animations';
import {Activity, Observation, ObservationType} from 'facade-api';

@Component({
  selector: 'app-activity-card',
  templateUrl: './activity-card.component.html',
  styleUrls: ['./activity-card.component.scss'],
  animations: [
    trigger(
      'inOutAnimation',
      [
        transition(
          ':enter',
          [
            style({ opacity: 0 }),
            animate('0.5s ease-out',
              style({opacity: 1 }))
          ]
        ),
        transition(
          ':leave',
          [
            style({ opacity: 1 })
          ]
        )
      ]
    )
  ]
})
export class ActivityCardComponent implements OnInit {
  @Input() public activity: Activity | undefined;
  public isExpanded = false;
  public ObservationType = ObservationType; // Exposed here so we can use actual enum in the html template
  constructor() { }

  ngOnInit(): void {
  }

  public getFeti(): string[] {
    return [...new Set(this.activity?.observations.map(observation => observation.fetus))];
  }

  public getMeasurement(type: ObservationType): Observation|undefined {
    return this.activity?.observations
      .filter(x => x.type === type)
      .sort((a, b) => b.dateOfMeasurement.getTime() - a.dateOfMeasurement.getTime())?.[0];
  }

  public getSingleMeasurementValue(type: ObservationType): string {
    const measurement = this.getMeasurement(type)?.values?.[0];
    if (!measurement) {
      return '?';
    }
    return `${measurement.value || ''} ${measurement.unit || ''}`;
  }

  public getBloodPressure(): string {
    const observation = this.getMeasurement(ObservationType.BloodPressure);
    if (!observation) {
      return '?';
    }
    const systolic = observation.values.find(x => x.name === 'Systolisk') || {value: '?'};
    const diastolic = observation.values.find(x => x.name === 'Diastolisk') || {value: '?'};

    return `${systolic.value}/${diastolic.value} ${systolic.unit || diastolic.unit}`;
  }

  getActivityStatusColor(status: string): string {
    if (status === 'planned') {
      return '#4228C4';
    } else if (status === 'expected') {
      return '#89C5CC';
    } else if (status === 'finished') {
      return '#646383';
    } else { return '#FFF'; }
  }
}
