import {Component, OnDestroy, OnInit, ViewChild} from '@angular/core';
import {ModalComponent} from '../../modal/modal.component';
import {FormControl, FormGroup, FormGroupDirective, Validators} from '@angular/forms';

@Component({
  selector: 'app-activity-modal',
  templateUrl: './activity-modal.component.html',
  styleUrls: ['./activity-modal.component.scss']
})
export class ActivityModalComponent implements OnInit, OnDestroy {
  @ViewChild('modal') public modalComponent: ModalComponent | undefined;
  @ViewChild('formDirective') public formDirective: FormGroupDirective | undefined;
  public activityForm: FormGroup | undefined;
  constructor() { }

  private readonly MAX_WEEK = 53;

  ngOnInit(): void {
    this.activityForm = new FormGroup({
      title: new FormControl(null, Validators.required),
      description: new FormControl(null, Validators.required),
      status: new FormControl('Forventet'),
      fromWeek: new FormControl(null, [Validators.required, Validators.min(0), Validators.max(this.MAX_WEEK)]),
      toWeek: new FormControl(null, [Validators.required, Validators.min(0), Validators.max(this.MAX_WEEK)])
    });
  }

  ngOnDestroy(): void {
    this.activityForm = undefined;
  }

  public submitActivity(activityForm: FormGroup | undefined, formDirective: FormGroupDirective | undefined): void {
    if (activityForm?.valid) {
      formDirective?.resetForm();
      this.setVisible(false);
    } else {
      activityForm?.markAllAsTouched();
    }
  }
  setVisible(isVisible: boolean): void {
    if (this.modalComponent) {
      this.modalComponent.setVisible(isVisible);
      this.formDirective?.resetForm();
    }
  }

  isVisible(): boolean {
    this.activityForm?.markAsUntouched();
    return !!this.modalComponent?.isModalVisible;
  }
}
