import {ChangeDetectionStrategy, Component, ElementRef, HostListener, OnDestroy, ViewChild} from '@angular/core';
import {Subscription} from 'rxjs';
import {DataSourceService} from './services/data-source.service';
import {MatDialog, MatDialogRef} from '@angular/material/dialog';
import {DialogComponent} from './dialog/dialog.component';
import {LoadingComponent} from './loading/loading.component';
import {FeedbackComponent} from './feedback/feedback.component';
import {UserContextService} from './services/user-context.service';
import {RoleSelectorComponent} from './role-selector/role-selector.component';

@Component({
  selector: 'app-root',
  templateUrl: './app.component.html',
  styleUrls: ['./app.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush
})
export class AppComponent implements OnDestroy {
  title = 'eGraviditet';
  patientName = 'Dame Kvindesen';
  private dataCardSubscription: Subscription;
  public dataIsLoading$ = this.dataSourceService.isLoading$;
  private loadingDialogRef: MatDialogRef<DialogComponent, any> | undefined = undefined;
  private roleSelectorDialogRef: MatDialogRef<RoleSelectorComponent, any> | undefined = undefined;
  private feedbackDialogRef: MatDialogRef<FeedbackComponent, any> | undefined = undefined;

  @ViewChild('sidebar') sidebar?: ElementRef<HTMLElement>;

  constructor(
    public dataSourceService: DataSourceService,
    public userContextService: UserContextService,
    public dialog: MatDialog
  ) {
    this.userContextService.userContext$.pipe(

    );
    // load data immediately'
    this.dataCardSubscription = this.dataSourceService.dummyDataCards$.subscribe();
    this.dataIsLoading$.subscribe(isLoading => {
      if (isLoading) {
        this.openLoadingDialog();
      } else {
        this.closeDialog(this.loadingDialogRef);
      }
    });
  }

  openLoadingDialog(): void {
    // prevent dangling dialogs
    if (!this.loadingDialogRef){
    this.loadingDialogRef = this.dialog.open(DialogComponent, {
      width: 'fit-content',
      data: {
        header: 'Henter data',
        component: LoadingComponent
      }
    });
    }
  }

  openChangeRoleDialog(): void {
    this.roleSelectorDialogRef = this.dialog.open(RoleSelectorComponent, {
      width: 'fit-content',
    });

  }

  private closeDialog(dialogRef: MatDialogRef<RoleSelectorComponent | DialogComponent | FeedbackComponent , any> | undefined ): void {
    if (dialogRef) {
      dialogRef.close();
    }
  }

  @HostListener('window:scroll')
  public allowYScrollFrame(): void {
    const supportPageOffset = window.pageXOffset !== undefined;
    const isCSS1Compat = ((document.compatMode || '') === 'CSS1Compat');
    const x = supportPageOffset ? window.pageXOffset : isCSS1Compat ? document.documentElement.scrollLeft : document.body.scrollLeft;
    const y = supportPageOffset ? window.pageYOffset : isCSS1Compat ? document.documentElement.scrollTop : document.body.scrollTop;
    if (this.sidebar?.nativeElement) {
      this.sidebar.nativeElement.style.left = `${-x}px`;
      if (y <= 72) {
        this.sidebar.nativeElement.style.top = `${72 - y}px`;
      }
    }
  }

  ngOnDestroy(): void {
    this.dataCardSubscription.unsubscribe();
  }

  openFeedbackDialog(): void {
    this.feedbackDialogRef = this.dialog.open(FeedbackComponent, {
      width: 'fit-content',
      data: {}
    });
  }
}
