import {BrowserModule} from '@angular/platform-browser';
import {LOCALE_ID, NgModule} from '@angular/core';
import {AppComponent} from './app.component';
import {HTTP_INTERCEPTORS, HttpClientModule} from '@angular/common/http';
import {environment} from '../environments/environment';
import {DataCardComponent} from './data-card/data-card.component';
import {ApiModule, BASE_PATH, DataCardService} from 'facade-api';
import {HttpMockRequestInterceptor} from '../utils/mock.interceptor';
import {HttpRequestInterceptor} from '../utils/interceptor';
import {AngularMaterialModule} from './modules/angular-material.module';
import {NavigationBarComponent} from './navigationbar/navigationbar.component';
import {RoutingModule} from './modules/routing.module';
import {ActivitiesComponent} from './activities/activities.component';
import {MeasurementsScreeningsComponent} from './measurements-screenings/measurements-screenings.component';
import {MeasurementsScansComponent} from './measurements-scans/measurements-scans.component';
import {MeasurementsSummaryComponent} from './measurements-summary/measurements-summary.component';
import {MeasurementsTabComponent} from './measurements-tab/measurements-tab.component';
import {DialogComponent} from './dialog/dialog.component';
import {BrowserAnimationsModule} from '@angular/platform-browser/animations';
import {LoadingComponent} from './loading/loading.component';
import {registerLocaleData} from '@angular/common';
import {LocalizationPipe} from './activities/localize';
import {MeasurementsMidwifeComponent} from './measurements-midwife/measurements-midwife.component';
import {FeedbackButtonComponent} from './feedback-button/feedback-button.component';
import {FeedbackComponent} from './feedback/feedback.component';
import {FormsModule, ReactiveFormsModule} from '@angular/forms';
import {ActivityCardComponent} from './activities/activity-card/activity-card.component';
import {DataFieldComponent} from './activities/data-field/data-field.component';
import localeDa from '@angular/common/locales/da';
import {CprSearchComponent} from './cpr-search/cpr-search.component';
import {NgxMaskModule} from 'ngx-mask';
import {NoActivePathwayComponent} from './data-card/no-active-pathway/no-active-pathway.component';
import {MatIconModule} from '@angular/material/icon';
import { ModalComponent } from './modal/modal.component';
import { ActivityModalComponent } from './activities/activity-modal/activity-modal.component';
import { FetusRelatedMeasurementsComponent } from './activities/activity-card/fetus-related-measurements/fetus-related-measurements.component';
import {RoleSelectorComponent} from './role-selector/role-selector.component';
import { TabsComponent } from './tabs/tabs.component';
import { PregnancyComponent } from './pregnancy/pregnancy.component';
import { GeneralInformationBarComponent } from './general-information-bar/general-information-bar.component';
import { GestationAgePipe } from './general-information-bar/gestation-age.pipe';

registerLocaleData(localeDa);

@NgModule({
  declarations: [
    AppComponent,
    DataCardComponent,
    NavigationBarComponent,
    ActivitiesComponent,
    DialogComponent,
    LoadingComponent,
    CprSearchComponent,
    NoActivePathwayComponent,
    MeasurementsMidwifeComponent,
    MeasurementsTabComponent,
    MeasurementsScreeningsComponent,
    MeasurementsScansComponent,
    MeasurementsSummaryComponent,
    FeedbackButtonComponent,
    FeedbackComponent,
    LocalizationPipe,
    ActivityCardComponent,
    DataFieldComponent,
    ModalComponent,
    ActivityModalComponent,
    FetusRelatedMeasurementsComponent,
    RoleSelectorComponent,
    TabsComponent,
    PregnancyComponent,
    GeneralInformationBarComponent,
    GestationAgePipe
  ],
    imports: [
        BrowserModule,
        BrowserAnimationsModule,
        HttpClientModule,
        ApiModule,
        AngularMaterialModule,
        RoutingModule,
        MatIconModule,
        FormsModule,
        ReactiveFormsModule,
        NgxMaskModule.forRoot(),
        RoutingModule,
    ],
  providers: [
    DataCardService,
    { provide: LOCALE_ID, useValue: 'da' },
    { provide: BASE_PATH, useValue: environment.base_path + '/api' },
    {
      provide: HTTP_INTERCEPTORS,
      useClass: environment.mock ? HttpMockRequestInterceptor : HttpRequestInterceptor,
      multi: true
    }
  ],
  bootstrap: [AppComponent]
})
export class AppModule {
  constructor() {

    console.log('Environment: ' + JSON.stringify(environment));
  }
}
