import {Component, OnDestroy} from '@angular/core';
import {FeedbackService} from '../services/feedback.service';
import {DialogComponent} from '../dialog/dialog.component';
import {MatDialogRef} from '@angular/material/dialog';
import {Subscription} from 'rxjs';
import {FormControl, FormGroup, Validators} from '@angular/forms';

@Component({
  selector: 'app-feedback',
  templateUrl: './feedback.component.html',
  styleUrls: ['./feedback.component.scss']
})
export class FeedbackComponent implements OnDestroy {
  private feedbackPostSubscription: Subscription | undefined;

  ratingToText: string[] = [
  '', // No rating selected yet
  'Jeg synes løsningen har mange væsentlige mangler',
  'Jeg synes løsningen har få men væsentlige mangler',
  'Jeg synes løsningen fungerer OK',
  'Jeg synes løsningen er rigtig god',
  'Jeg elsker løsningen!'
  ];

  public form = new FormGroup({
    rating: new FormControl('', Validators.required),
    comment: new FormControl(''),
  });
  public loading = false;

  constructor(private service: FeedbackService, private dialogRef: MatDialogRef<DialogComponent>) {
  }

  sendFeedback(): void {
  if (this.form.valid){
    this.loading = true;
    this.feedbackPostSubscription = this.service.sendFeedback(
      {rating: this.form.value.rating, comment: this.form.value.comment}
    ).subscribe(
        _ => {
          console.log('Successfully sent feedback');
          this.dialogRef.close();
        }
      );
  }
  }

  ngOnDestroy(): void {
    if (this.feedbackPostSubscription) {
      this.feedbackPostSubscription.unsubscribe();
    }
  }
}
