import {ComponentFixture, fakeAsync, TestBed} from '@angular/core/testing';

import {GeneralInformationBarComponent} from './general-information-bar.component';
import {AppModule} from '../app.module';
import {of} from 'rxjs';
import {DataSourceService} from '../services/data-source.service';
import {DataCardResponse} from 'facade-api';
import {OverallAssessmentSectionPrenatalCareAssessment} from '../../../projects/facade-api/model/overallAssessmentSectionPrenatalCareAssessment';
import {YesNoEnum} from '../../../projects/facade-api';

describe('GeneralInformationBarComponent', () => {
  let component: GeneralInformationBarComponent;
  let fixture: ComponentFixture<GeneralInformationBarComponent>;

  beforeEach(async () => {
    const spy = {
      dummyDataCards$: of([{
        episodeOfCareIdentifier: '1',
        recordTarget: {
          identifier: '1111111111',
          name: {
            firstNames: ['Peter'],
            middleNames: ['The'],
            lastName: 'Meter',
          }
        },
        chronicalDiseasesSection: {
          circulatorySystem: YesNoEnum.YES,
          respitorySystem: YesNoEnum.YES,
          thyroid: YesNoEnum.NO,
          diabetes: YesNoEnum.YES,
        },
        overallAssessmentSection: {
          prenatalCareAssessment: {
            assessment: 'this aint good',
            numberOfFetuses: 1,
            careLevel: OverallAssessmentSectionPrenatalCareAssessment.CareLevelEnum.Basic
          }
        }
      } as DataCardResponse])
    };
    await TestBed.configureTestingModule({
      declarations: [ GeneralInformationBarComponent ],
      imports: [AppModule],
      providers: [
        {provide: DataSourceService, useValue: spy}
      ]
    })
    .compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(GeneralInformationBarComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  it('computes care-level display-text on init', () => {
    expect(component.careLevel).toEqual('1');
  });

  it('computes care-level display-text correctly', () => {
    const componentWithExposedMethod = component as unknown as
      {computeCareLevel(carelevel?: OverallAssessmentSectionPrenatalCareAssessment.CareLevelEnum): string};
    expect(componentWithExposedMethod.computeCareLevel(undefined)).toEqual('?');
    expect(componentWithExposedMethod.computeCareLevel(
      OverallAssessmentSectionPrenatalCareAssessment.CareLevelEnum.Basic)
    ).toEqual('1');
    expect(componentWithExposedMethod.computeCareLevel(
      OverallAssessmentSectionPrenatalCareAssessment.CareLevelEnum.Extended)
    ).toEqual('2');
    expect(componentWithExposedMethod.computeCareLevel(
      OverallAssessmentSectionPrenatalCareAssessment.CareLevelEnum.SpecialistMultidisciplinaryTeam
    )).toEqual('3');
    expect(componentWithExposedMethod.computeCareLevel(
      OverallAssessmentSectionPrenatalCareAssessment.CareLevelEnum.HighRiskPregnancyCare
    )).toEqual('4');
  });

  it('computes special conditions display-text', fakeAsync(() => {
    expect(component.chronicalDeceases).toEqual('Kredsløbssygdomme, Åndedrætssystem, Diabetes');
  }));
});
