import { Component, OnInit } from '@angular/core';
import {DataSourceService} from '../services/data-source.service';
import {ChronicDiseasesSection, DataCard} from 'facade-api';
import {
  OverallAssessmentSectionPrenatalCareAssessment
} from '../../../projects/facade-api/model/overallAssessmentSectionPrenatalCareAssessment';

@Component({
  selector: 'app-general-information-bar',
  templateUrl: './general-information-bar.component.html',
  styleUrls: ['./general-information-bar.component.scss']
})
export class GeneralInformationBarComponent implements OnInit {
  public dataCard: DataCard | undefined;
  public chronicalDeceases = 'Nej';
  public careLevel = '?';
  constructor(private dataSourceService: DataSourceService) { }

  ngOnInit(): void {
    this.dataSourceService.dummyDataCards$
      .subscribe((dataCards) => {
        this.dataCard = dataCards[0];
        this.chronicalDeceases = this.computeSpecialConditions(this.dataCard.chronicalDiseasesSection || {});
        this.careLevel = this.computeCareLevel(this.dataCard.overallAssessmentSection?.prenatalCareAssessment?.careLevel);
      });
  }

  private computeCareLevel(carelevel?: OverallAssessmentSectionPrenatalCareAssessment.CareLevelEnum): string {
    if (!carelevel) {
      return '?';
    }
    switch (carelevel) {
      case 'basic':
        return '1';
      case 'extended':
        return '2';
      case 'specialistMultidisciplinaryTeam':
        return '3'
      case 'highRiskPregnancyCare':
        return '4';
    }
  }

  private computeSpecialConditions(conditions: ChronicDiseasesSection): string {
    return Object.keys(conditions)
      // tslint:disable-next-line:no-non-null-assertion - it was literally checked in line above!
      .filter(key => (this.dataCard!.chronicalDiseasesSection as any)[key] === 'yes')
      .map(key => {
        switch (key) {
          case 'circulatorySystem':
            return 'Kredsløbssygdomme';
          case 'respitorySystem':
            return 'Åndedrætssystem';
          case 'thyroid':
            return 'Skjoldbruskkirtel';
          case 'diabetes':
            return 'Diabetes';
          default:
            return '';
        }
      })
      .join(', ') || 'Nej';
  }

}
