import {Injectable} from '@angular/core';
import {BehaviorSubject, combineLatest, Observable, Subject} from 'rxjs';
import {CarePlan, CarePlanService, DataCardResponse, DataCardService} from 'facade-api';
import {delay, map, shareReplay, switchMap, tap} from 'rxjs/operators';
import {environment} from '../../environments/environment';
import {UserContextService} from './user-context.service';
import {ApplicationContext} from 'facade-api';

/**
 * Shared data service
 */
@Injectable({
  providedIn: 'root'
})
export class DataSourceService {
  // activate data Loading
  private innerDataLoadingActivator: Subject<undefined> = new BehaviorSubject(undefined);

  // load data when innerDataLoadingActivator is emitting and when role is selected
  private dataLoadingActivator: Observable<undefined> = combineLatest(
    [
      this.innerDataLoadingActivator,
      this.userContextService.selectedRole$
      ]
  ).pipe(map(_ => undefined));

  private isLoading: BehaviorSubject<boolean> = new BehaviorSubject<boolean>(false);
  public isLoading$: Observable<boolean> = this.isLoading.asObservable();

  private applicationContext: ApplicationContext = this.getCookie('application-context');

  constructor(
    private carePlanService: CarePlanService,
    private dataCardService: DataCardService,
    private userContextService: UserContextService
  ) {}



  public dummyDataCards$: Observable<Array<DataCardResponse>> = this.dataLoadingActivator.pipe(
    tap(() => this.isLoading.next(true)),
    switchMap(() => this.dataCardService.maternityDataCardGet(this.applicationContext)),
    delay(!environment.production ? 2000 : 0),
    shareReplay(),
    tap(() => this.isLoading.next(false))
  );

  public carePlan$: Observable<Array<CarePlan>> = this.dataLoadingActivator.pipe(
    switchMap(() => this.carePlanService.maternityCarePlanGet(this.applicationContext)),
    delay(!environment.production ? 2000 : 0),
    shareReplay(),
  );

  public refresh(): void{
    this.innerDataLoadingActivator.next(undefined);
  }

  private getCookie<T>(name: string): T {
    const cookies: Array<string> = document.cookie.split(';');
    const numberOfCookies: number = cookies.length;
    const cookieName = `${name}=`;
    let c: string;

    for (let i = 0; i < numberOfCookies; i += 1) {
      c = cookies[i].replace(/^\s+/g, '');
      if (c.indexOf(cookieName) === 0) {
        return JSON.parse(c.substring(cookieName.length, c.length)) as T;
      }
    }
    return {} as T;
  }
}
