import {TestBed} from '@angular/core/testing';
import {UserContext, UserContextService} from './user-context.service';
import {HttpClientTestingModule, HttpTestingController} from '@angular/common/http/testing';
import {environment} from '../../environments/environment';
import {getLocalStorageRole} from '../../utils/localstorage';


describe('UserContextService', () => {
  let service: UserContextService;
  let httpTestController: HttpTestingController;

  const testUserContext: UserContext = {
    commonName: 'Lars Larsen',
    organizationName: 'Test',
    eligibleRoles: [
      {
        authorizationCode: 'J0184',
        educationCode: '7170',
        educationType: 'Læge'
      },
      {
        authorizationCode: 'J0184',
        educationCode: '7170',
        educationType: 'Jordemoder'
      }
    ]
  };

  beforeEach(() => {
    TestBed.configureTestingModule({
      imports: [HttpClientTestingModule]
    });
    httpTestController = TestBed.inject(HttpTestingController);
    service = TestBed.inject(UserContextService);
  });

  it('should be created', () => {
    expect(service).toBeTruthy();
  });

  it('should fetch userContext', (done) => {
    service.userContext$.subscribe(
    res => {
      expect(res).toBeDefined();
      done();
    }
    );
    httpTestController.expectOne(environment.base_path + '/api' + '/usercontext').flush(testUserContext);
  });

  it('should select role and save to local storage when only one is eligible', (done) => {
    // copy test context and remove one role
    const singleRoleUser = Object.assign({}, testUserContext);
    singleRoleUser.eligibleRoles.pop();

    service.selectedRole$.subscribe(
      res => {
        expect(res).toBeDefined();
        done();
      }
    );
    service.localStorageKeyValue$.subscribe(
      ([role, usercontext]) => {
        expect( getLocalStorageRole(usercontext)).toBeDefined();
      }
    );
    httpTestController.expectOne(environment.base_path + '/api' + '/usercontext').flush(singleRoleUser);
  });

  it('should select role', (done) => {
    service.selectedRole$.subscribe(res =>  {
      expect(res).toBeDefined();
      done();
    }
    );
    service.selectRole(testUserContext.eligibleRoles[0]);
  });
});
