import {
  AfterViewChecked,
  AfterViewInit,
  Component,
  ContentChildren,
  Input,
  OnInit,
  QueryList,
  ViewChild,
  ViewChildren
} from '@angular/core';
import {MatTab, MatTabGroup} from '@angular/material/tabs';

@Component({
  selector: 'app-tabs',
  templateUrl: './tabs.component.html',
  styleUrls: ['./tabs.component.scss']
})
/**
 * This component is pretty entangled with the material tabs component
 * - this is just here to provide a handy and styled short-hand for using the material
 * component.
 */
export class TabsComponent implements AfterViewInit, AfterViewChecked {
  @Input() title: string|undefined;
  @ViewChild(MatTabGroup) matTabGroup: MatTabGroup|undefined;
  @ContentChildren(MatTab, {descendants: true}) tabsFromNgContent: QueryList<MatTab>|undefined;

  constructor() { }

  ngAfterViewInit(): void{
    if (this.tabsFromNgContent) {
      // Add transcluded tabs to the view
      this.matTabGroup?._tabs.reset([...this.tabsFromNgContent.toArray()]);
      this.matTabGroup?._tabs.notifyOnChanges();
    }
  }

  ngAfterViewChecked(): void {
    if (this.tabsFromNgContent) {
      const tabElements = this.matTabGroup?._elementRef?.nativeElement.childNodes[0].getElementsByClassName('mat-tab-label');
      if (tabElements == null || tabElements.length === 0) {
        return;
      }

      // Compute with required to take up the fill width
      const computedWidth = `${100 / this.tabsFromNgContent?.length}%`;
      const tabs: HTMLDivElement[] = [...tabElements];
      tabs.forEach(tab => tab.style.width = computedWidth);
    }
  }


}
