import {Injectable} from '@angular/core';
import {HttpEvent, HttpHandler, HttpInterceptor, HttpRequest, HttpResponse} from '@angular/common/http';
import {Observable} from 'rxjs';
import {catchError, map} from 'rxjs/operators';
import {handleError} from './errorHandling';
import {JsonTransformerUtil} from './json-transformer.util';

@Injectable()
export class HttpRequestInterceptor implements HttpInterceptor {
  intercept(request: HttpRequest<any>, next: HttpHandler): Observable<HttpEvent<any>> {
    return next.handle(request).pipe(
      map((event: HttpEvent<any>) => {
        if (event instanceof HttpResponse) {
          const replaced = JsonTransformerUtil.transformDates(event.body);
          return event.clone({body: replaced});
        }
        return event;
      }),
      catchError(handleError)
    );
  }

}
